==> nextcloud-24.0.10.tgz: nextcloud/apps/oauth2/l10n/pl.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Twoja aplikacja klienta nie posiada autoryzacji do połączenia. Poinformuj proszę administratora klienta.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Adres przekierowania musi być pełnym adresem URL, np.: https://twojadomena.com/sciezka",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Umożliwia uwierzytelnianie zgodne z OAuth2 innych aplikacji internetowych.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "Aplikacja OAuth2 umożliwia administratorom modyfikację wbudowanego uwierzytelnienia, pozwalając na korzystanie z OAuth2 innych aplikacji internetowych.",
    "OAuth 2.0 clients" : "Klienci OAuth 2.0",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 pozwala zewnętrznym serwisom na korzystanie z dostępu do {instanceName}.",
    "Add client" : "Dodaj klienta",
    "Name" : "Nazwa",
    "Redirection URI" : "URI przekierowania",
    "Add" : "Dodaj",
    "Client Identifier" : "Identyfikator Klienta",
    "Secret" : "Tajny klucz",
    "Show client secret" : "Pokaż tajny klucz klienta",
    "Delete" : "Usuń"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-27.1.4.tgz: nextcloud/apps/oauth2/l10n/pl.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Twoja aplikacja klienta nie posiada autoryzacji do połączenia. Poinformuj proszę administratora klienta.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Adres przekierowania musi być pełnym adresem URL, np.: https://twojadomena.com/sciezka",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Umożliwia uwierzytelnianie zgodne z OAuth2 innych aplikacji internetowych.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "Aplikacja OAuth2 umożliwia administratorom modyfikację wbudowanego uwierzytelnienia, pozwalając na korzystanie z OAuth2 innych aplikacji internetowych.",
    "OAuth 2.0 clients" : "Klienci OAuth 2.0",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 pozwala zewnętrznym serwisom na korzystanie z dostępu do {instanceName}.",
    "Name" : "Nazwa",
    "Redirection URI" : "URI przekierowania",
    "Client Identifier" : "Identyfikator Klienta",
    "Secret key" : "Tajny klucz",
    "Add client" : "Dodaj klienta",
    "Add" : "Dodaj",
    "Show client secret" : "Pokaż tajny klucz klienta",
    "Delete" : "Usuń",
    "Secret" : "Tajny klucz"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
